#ifndef __LIBRARY_H__
#define __LIBRARY_H__

#ifdef DLL_EXPORT
    #define DLLTYPE __declspec(dllexport)
#else
    #define DLLTYPE __declspec(dllimport)
#endif //DLL_EXPORT

#if _MSC_VER > 1000

#pragma once

#endif // _MSC_VER > 1000

#define BUFSIZE 256

#define FPMC_OK	0
#define FPMC_INVALID_PORT	1
#define FPMC_INVALID_BAUDRATE	2
#define FPMC_INVALID_NODE	3
#define FPMC_INVALID_AXIS	4
#define FPMC_INVALID_DATA	5
#define FPMC_INVLID_COMMUNICATION	6
#define FPMC_CRC_ERROR	7
#define FPMC_NO_RESPONSE_MESSAGE	8

#define FPMC_BAUD_9600	9600
#define FPMC_BAUD_19200	19200
#define FPMC_BAUD_38400	38400
#define FPMC_BAUD_57600	57600
#define FPMC_BAUD_115200	115200

#define FPMC_INSTANT	0
#define FPMC_SLOW	1

#define FPMC_INSTANTSTOP	0
#define FPMC_SLOWSTOP	1

#define FPMC_HSTOP0	0
#define FPMC_HSTOP1	1
#define FPMC_HSTOP2	2

#define FPMC_INPORT0	0
#define FPMC_INPORT1	1

#define FPMC_OUTPORT0	0
#define FPMC_OUTPORT1	1

#define FPMC_LOW	0
#define FPMC_HIGH	1

#define FPMC_DISABLE	0
#define FPMC_ENABLE		1

#define FPMC_SOFLMT_MINUS	0
#define FPMC_SOFLMT_PLUS	1

#define FPMC_OFF 0
#define	FPMC_ON	1

#define FPMC_SETPULSE1 1
#define FPMC_SETPULSE2 2

#define FPMC_X_AXIS	0
#define FPMC_Y_AXIS	1
#define FPMC_X_Y_AXIS 2

#define Node01 0x01
#define Node02 0x02
#define Node03 0x03
#define Node04 0x04
#define Node05 0x05
#define Node06 0x06
#define Node07 0x07
#define Node08 0x08
#define Node09 0x09
#define Node10 0x0A
#define Node11 0x0B
#define Node12 0x0C
#define Node13 0x0D
#define Node14 0x0E
#define Node15 0x0F
#define Node16 0x10
#define Broadcast 0x80

extern "C" __declspec(dllimport) long __fastcall CalculateManualDecelPoint(const int Range,
	long Acceleration, long Deceleration, long StVelocity, long DrVelocity,
	const int CtXaxis, const int CtYaxis, const int EndXaxis, const int EndYaxis,
	const BOOL CW, const BOOL FLS);
	
extern "C" __declspec(dllimport) void __fastcall CalTotShortPulse(const bool CW, const double BeginArcXaxis,
	const double BeginArcYaxis, const double EndArcXaxis, const double EndArcYaxis,
	const double Radius2, const int BeginPhase, const int EndPhase, long &TotalShortPulse,
	double &BeginPhasePulse, double &EndPhasePulse, int &NumberOfPassPhase);

extern "C" __declspec(dllimport) int autpmc_Open(int PortNum, int BaudRate);

extern "C" __declspec(dllimport) int autpmc_SetBaudrate(int PortNum, char nNodeId, int BaudRate);

extern "C" __declspec(dllimport) int autpmc_Timeout(int PortNum, int RITimeout, int RTTimeoutMultiplier, int RTTimeoutConstant, int WTTimeoutMultiplier, int WTTimeoutConstant);

extern "C" __declspec(dllimport) int autpmc_Read(int PortNum);

extern "C" __declspec(dllimport) int autpmc_Send(int PortNum, char* nData, int data_length);

extern "C" __declspec(dllimport) int autpmc_Close(int PortNum);

extern "C" __declspec(dllimport) int autpmc_ClrINCPos(int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_ClrABSPos(int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_SetDrvSpd(int PortNum, char nNodeId, char axis, int nDrvIndex);

extern "C" __declspec(dllimport) int autpmc_SetStrSpd(int PortNum, char nNodeId, char axis, int iStrSpd);

extern "C" __declspec(dllimport) int autpmc_GetStrSpd(int PortNum, char nNodeId, char axis, int *iStrSpd);

extern "C" __declspec(dllimport) int autpmc_HomRun (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_HomStop (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_ABSMove (int PortNum, char nNodeId, char axis, long lPos);

extern "C" __declspec(dllimport) int autpmc_INCMove (int PortNum, char nNodeId, char axis, long lPos);

extern "C" __declspec(dllimport) int autpmc_LIDMove (int PortNum, char nNodeId, BOOL bFLS, long lXEndPos, long lYEndPos);

extern "C" __declspec(dllimport) int autpmc_CIDMove (int PortNum, char nNodeId, BOOL bFLS, long lRadius, long lMDP);

extern "C" __declspec(dllimport) int autpmc_FIDMove (int PortNum, char nNodeId, BOOL bFLS, long lXCenPos, long lYCenPos, long lXEndPos, long lYEndPos, long lMDP);

extern "C" __declspec(dllimport) int autpmc_RIDMove (int PortNum, char nNodeId, BOOL bFLS, long lXCenPos, long lYCenPos, long lXEndPos, long lYEndPos, long lMDP);

extern "C" __declspec(dllimport) int autpmc_SlowStop(int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_EmgStop(int PortNum, char nNodeId);

extern "C" __declspec(dllimport) int autpmc_SetSpdMul (int PortNum, char nNodeId, char axis, int iSpdMul);

extern "C" __declspec(dllimport) int autpmc_GetSpdMul (int PortNum, char nNodeId, char axis, int *iSpdMul);

extern "C" __declspec(dllimport) int autpmc_SetJrkSpd (int PortNum, char nNodeId, char axis, int iJrkSpd);

extern "C" __declspec(dllimport) int autpmc_GetJrkSpd (int PortNum, char nNodeId, char axis, int *iJrkSpd);

extern "C" __declspec(dllimport) int autpmc_SetAccSpdRate (int PortNum, char nNodeId, char axis, int iAccSpdRate);

extern "C" __declspec(dllimport) int autpmc_GetAccSpdRate (int PortNum, char nNodeId, char axis, int *iAccSpdRate);

extern "C" __declspec(dllimport) int autpmc_SetDecSpdRate (int PortNum, char nNodeId, char axis, int iDecSpdRate);

extern "C" __declspec(dllimport) int autpmc_GetDecSpdRate (int PortNum, char nNodeId, char axis, int *iDecSpdRate);

extern "C" __declspec(dllimport) int autpmc_GetCurDrvSpd(int PortNum, char nNodeId, char axis, int *iDrvSpd); 

extern "C" __declspec(dllimport) int autpmc_SetDrvSpdPgm (int PortNum, char nNodeId, char axis, int nDrvIndex, int iDrvSpd);

extern "C" __declspec(dllimport) int autpmc_GetDrvSpdPgm (int PortNum, char nNodeId, char axis, int nDrvIndex, int *iDrvSpd); 

extern "C" __declspec(dllimport) int autpmc_SetSofLmt (int PortNum, char nNodeId, char axis, int iDirection, long lSoftLmt);

extern "C" __declspec(dllimport) int autpmc_GetSofLmt (int PortNum, char nNodeId, char axis, int iDirection, long *lSoftLmt);

extern "C" __declspec(dllimport) int autpmc_SetEndPWidth (int PortNum, char nNodeId, char axis, int iEndPWidth);

extern "C" __declspec(dllimport) int autpmc_GetEndPWidth (int PortNum, char nNodeId, char axis, int *iEndPWidth);

extern "C" __declspec(dllimport) int autpmc_SetPulSclNum (int PortNum, char nNodeId, char axis, int dPulScl);

extern "C" __declspec(dllimport) int autpmc_GetPulSclNum (int PortNum, char nNodeId, char axis, int *dPulScl);

extern "C" __declspec(dllimport) int autpmc_SetPulSclDen (int PortNum, char nNodeId, char axis, int dPulScl);

extern "C" __declspec(dllimport) int autpmc_GetPulSclDen (int PortNum, char nNodeId, char axis, int *dPulScl);

extern "C" __declspec(dllimport) int autpmc_SetHomSpd (int PortNum, char nNodeId, char axis, BOOL bSpd, int iSpd);

extern "C" __declspec(dllimport) int autpmc_GetHomSpd (int PortNum, char nNodeId, char axis, BOOL bSpd, int *iSpd);

extern "C" __declspec(dllimport) int autpmc_SetHomOffset(int PortNum, char nNodeId, char axis, long lOffset);

extern "C" __declspec(dllimport) int autpmc_GetHomOffset(int PortNum, char nNodeId, char axis, long *lOffset);

extern "C" __declspec(dllimport) int autpmc_SetTimPgm (int PortNum, char nNodeId, char axis, int nIndex, int iPostTim);

extern "C" __declspec(dllimport) int autpmc_GetTimPgm (int PortNum, char nNodeId, char axis, int nIndex, int *iPostTim);

extern "C" __declspec(dllimport) int autpmc_SetLmtStopMod(int PortNum, char nNodeId, char axis, BOOL bInstant);

extern "C" __declspec(dllimport) int autpmc_GetLmtStopMod(int PortNum, char nNodeId, char axis, BOOL *bStopType);

extern "C" __declspec(dllimport) int autpmc_SetLmtActLev (int PortNum, char nNodeId, char axis, BOOL bLmtActLev);

extern "C" __declspec(dllimport) int autpmc_GetLmtActLev(int PortNum, char nNodeId, char axis, BOOL *bLevel);

extern "C" __declspec(dllimport) int autpmc_SetSCurve (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetSCurve (int PortNum, char nNodeId, char axis, BOOL *bEnable);

extern "C" __declspec(dllimport) int autpmc_SetEndPEnable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetEndPEnable (int PortNum, char nNodeId, char axis, BOOL *bEnable);

extern "C" __declspec(dllimport) int autpmc_SetDecValue (int PortNum, char nNodeId, char axis, BOOL bDec);

extern "C" __declspec(dllimport) int autpmc_GetDecValue (int PortNum, char nNodeId, char axis, BOOL *bDec);

extern "C" __declspec(dllimport) int autpmc_SetSofLmtEnable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetSofLmtEnable (int PortNum, char nNodeId, char axis, BOOL *bEnable);

extern "C" __declspec(dllimport) int autpmc_SetPowHomStart (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetPowHomStart (int PortNum, char nNodeId, char axis, BOOL *bEnable);

extern "C" __declspec(dllimport) int autpmc_SetPowPgmStart (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetPowPgmStart (int PortNum, char nNodeId, char axis, BOOL *bEnable);

extern "C" __declspec(dllimport) int autpmc_SetInputLev (int PortNum, char nNodeId, char axis, BOOL bInPort, BOOL bActLev);

extern "C" __declspec(dllimport) int autpmc_GetInputLev (int PortNum, char nNodeId, char axis, BOOL bInPort, BOOL *bActLev);

extern "C" __declspec(dllimport) int autpmc_SetPulseType (int PortNum, char nNodeId, int iPulseType);

extern "C" __declspec(dllimport) int autpmc_GetPulseType (int PortNum, char nNodeId, int *iPulseType);

extern "C" __declspec(dllimport) int autpmc_Step1Enable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_Step1Direction (int PortNum, char nNodeId, char axis, BOOL bDirection);

extern "C" __declspec(dllimport) int autpmc_Step2Enable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_Step2Direction (int PortNum, char nNodeId, char axis, BOOL bDirection);

extern "C" __declspec(dllimport) int autpmc_Step3Enable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_Step3Direction (int PortNum, char nNodeId, char axis, BOOL bDirection);

extern "C" __declspec(dllimport) int autpmc_Step4Enable (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_Step4Direction (int PortNum, char nNodeId, char axis, BOOL bDirection);

extern "C" __declspec(dllimport) int autpmc_SetHomEndPosClr (int PortNum, char nNodeId, char axis, BOOL bEnable);

extern "C" __declspec(dllimport) int autpmc_GetHomEndPosClr (int PortNum, char nNodeId, char axis, BOOL *bClear);

extern "C" __declspec(dllimport) int autpmc_SetHomSigLev (int PortNum, char nNodeId, char axis, int nHomSigNo, BOOL bLevel);

extern "C" __declspec(dllimport) int autpmc_GetHomSigLev (int PortNum, char nNodeId, char axis, int nHomSigNo, BOOL *bLevel);

extern "C" __declspec(dllimport) int autpmc_SetHomMod(int PortNum, char nNodeId, char axis, int nStepNo, BOOL bEnable, BOOL bDirection);

extern "C" __declspec(dllimport) struct HOMMOD *autpmc_GetHomMod(int PortNum, char nNodeId, char axis, int nStepNo, HOMMOD *pMode);

extern "C" __declspec(dllimport) int autpmc_PgmABS (int PortNum, char nNodeId, char axis, int nStepNo, long lPos, int nSpeed, int nTimer, BOOL bEndP, BOOL bBoth);

extern "C" __declspec(dllimport) int autpmc_PgmINC (int PortNum, char nNodeId, char axis, int nStepNo, long lPos, int nSpeed, int nTimer, BOOL bEndP, BOOL bBoth);

extern "C" __declspec(dllimport) int autpmc_PgmHOM (int PortNum, char nNodeId, char axis, int nStepNo, BOOL bEndP, BOOL bBoth);

extern "C" __declspec(dllimport) int autpmc_PgmLID (int PortNum, char nNodeId, int nStepNo, long lXEndPos, long lYEndPos, BOOL bFLS, int nSpeed, int nTimer, BOOL bEndP);

extern "C" __declspec(dllimport) int autpmc_PgmCID (int PortNum, char nNodeId, int nStepNo, long lRadius, BOOL bFLS, int nSpeed, int nTimer, BOOL bEndP);

extern "C" __declspec(dllimport) int autpmc_PgmFID (int PortNum, char nNodeId, int nStepNo, long XCenPos, long XEndPos, long YCenPos, long YEndPos, BOOL bFLS, int nSpeed, int nTimer, BOOL bEndP);

extern "C" __declspec(dllimport) int autpmc_PgmRID (int PortNum, char nNodeId, int nStepNo, long XCenPos, long XEndPos, long YCenPos, long YEndPos, BOOL bFLS, int nSpeed, int nTimer, BOOL bEndP);

extern "C" __declspec(dllimport) int autpmc_PgmICJ (int PortNum, char nNodeId, char axis, int nStepNo, int nJumpStep, int nInputPtNo);

extern "C" __declspec(dllimport) int autpmc_PgmIRD (int PortNum, char nNodeId, char axis, int nStepNo, int nInputPtNo);

extern "C" __declspec(dllimport) int autpmc_PgmOPC (int PortNum, char nNodeId, char axis, int nStepNo, int nInputPtNo, BOOL bON);

extern "C" __declspec(dllimport) int autpmc_PgmOPT (int PortNum, char nNodeId, char axis, int nStepNo, int nOutPtNo, int iOnTim, BOOL bNextStep);

extern "C" __declspec(dllimport) int autpmc_PgmJMP (int PortNum, char nNodeId, char axis, int nStepNo, int nJumpStep);

extern "C" __declspec(dllimport) int autpmc_PgmREP (int PortNum, char nNodeId, char axis, int nStepNo, int nRepCnt);

extern "C" __declspec(dllimport) int autpmc_PgmRPE (int PortNum, char nNodeId, char axis, int nStepNo);

extern "C" __declspec(dllimport) int autpmc_PgmEND (int PortNum, char nNodeId, char axis, int nStepNo);

extern "C" __declspec(dllimport) int autpmc_PgmTIM (int PortNum, char nNodeId, char axis, int nStepNo, int nOnTim);

extern "C" __declspec(dllimport) int autpmc_PgmNOP (int PortNum, char nNodeId, char axis, int nStepNo);

extern "C" __declspec(dllimport) int autpmc_PgmRun (int PortNum, char nNodeId, char axis, int iStepNo);

extern "C" __declspec(dllimport) int autpmc_PgmStepRun (int PortNum, char nNodeId, char axis, int iStepNo);

extern "C" __declspec(dllimport) int autpmc_PgmPause (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_PgmReRun (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_PgmStop (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_DelPgmDataAll (int PortNum, char nNodeId, char axis);

extern "C" __declspec(dllimport) int autpmc_DelPgmData (int PortNum, char nNodeId, char axis, int nStepNo);

extern "C" __declspec(dllimport) int autpmc_Reset (int PortNum, char nNodeId);
 
extern "C" __declspec(dllimport) int autpmc_Init (int PortNum, char nNodeId);
 
extern "C" __declspec(dllimport) int autpmc_IsCon (int PortNum, char nNodeId, BOOL *bOn);

extern "C" __declspec(dllimport) struct PMC_PARADATA *autpmc_GetParaAll (int PortNum, char nNodeId, char axis, PMC_PARADATA *pData);

extern "C" __declspec(dllimport) struct PMC_PARADATA *autpmc_GetParaOPMAll (int PortNum, char nNodeId, char axis, PMC_PARADATA *pData);

extern "C" __declspec(dllimport) struct PMC_PARADATA *autpmc_GetParaPMAll (int PortNum, char nNodeId, char axis, PMC_PARADATA *pData);

extern "C" __declspec(dllimport) struct PMC_PARADATA *autpmc_GetParaHSMAll (int PortNum, char nNodeId, char axis, PMC_PARADATA *pData);

extern "C" __declspec(dllimport) int autpmc_GetCurPos (int PortNum, char nNodeId, char axis, long *lCurPos);

extern "C" __declspec(dllimport) int autpmc_GetCurPgmNo (int PortNum, char nNodeId, char axis, int *iCurPgmNo);

extern "C" __declspec(dllimport) struct PMC_ERRORSTATE *autpmc_GetErrorSt (int PortNum, char nNodeId, char axis, PMC_ERRORSTATE *pError);

extern "C" __declspec(dllimport) struct PMC_RUNSTATE *autpmc_IsRun (int PortNum, char nNodeId, char axis, PMC_RUNSTATE *pRun);

extern "C" __declspec(dllimport) struct PMC_SOFTVERSION *autpmc_GetModName (int PortNum, char nNodeId, PMC_SOFTVERSION *pVersion);
 
extern "C" __declspec(dllimport) struct PMC_SOFTVERSION *autpmc_GetSofVer (int PortNum, char nNodeId, PMC_SOFTVERSION *pVersion);

extern "C" __declspec(dllimport) int autpmc_ContMove (int PortNum, char nNodeId, char axis, BOOL bDirection);

extern "C" __declspec(dllimport) struct PARALLELSTATE *autpmc_GetParallelIO (int PortNum, char nNodeId, PARALLELSTATE *pState);

extern "C" __declspec(dllimport) struct AXISSTATE *autpmc_GetAxisIO (int PortNum, char nNodeId, char axis, AXISSTATE *pState);

extern "C" __declspec(dllimport) int autpmc_SetUserOut (int PortNum, char nNodeId, char axis, BOOL bPort, BOOL bOn);


#ifndef  MYHEADER
#define MYHEADER

typedef struct PMC_PARADATA
{
	int iErrorState;
	BOOL bLmtStopMod[2];
	BOOL bLmtActLev[2];
	BOOL bSCurve[2];
	BOOL bEndPEnable[2];
	BOOL bDecValue[2];
	BOOL bSofLmtEnable[2];
	BOOL bPowHomStart[2];
	BOOL bPowPgmStart[2];
	BOOL bInput0Lev[2];
	BOOL bInput1Lev[2];
	int iPulseType;
	int iSpdMul[2];
	int iJrkSpd[2];
	int iAccSpdRate[2];
	int iDecSpdRate[2];
	int iStrSpd[2];
	int iDrvSpd[2]; 
	int iDrvSpd1Pgm[2];
	int iDrvSpd2Pgm[2];
	int iDrvSpd3Pgm[2];
	int iDrvSpd4Pgm[2];
	int iTim1Pgm[2];
	int iTim2Pgm[2];
	int iTim3Pgm[2];
	long lSofLmtP[2];
	long lSofLmtM[2];
	int iEndPWidth[2];
	int iPulSclNum[2];
	int iPulSclDen[2];
	BOOL bHomMod1[2];
	BOOL bHomMod1Dir[2];
	BOOL bHomMod2[2];
	BOOL bHomMod2Dir[2];
	BOOL bHomMod3[2];
	BOOL bHomMod3Dir[2];
	BOOL bHomMod4[2];
	BOOL bHomMod4Dir[2];
	BOOL bHomEndPosClr[2];
	BOOL bHomSig0Lev[2];
	BOOL bHomSig1Lev[2];
	BOOL bHomSig2Lev[2];
	int iHomLowSpd[2];
	int iHomHighSpd[2];
	long lHomOffset[2];

} PMC_PARADATA;

typedef struct PMC_SOFTVERSION
{
	int iErrorState;
	char cModName[11];
	char cSofVer[7];

} PMC_SOFTVERSION;

typedef struct PMC_ERRORSTATE
{
	int iErrorState;
	BOOL bSofLmtErrP[2];
	BOOL bSofLmtErrM[2];
	BOOL bHardLmtErrP[2];
	BOOL bHardLmtErrM[2];
	BOOL bEmgErr[2];
	BOOL bPgmErr[2];
	BOOL bHomErr[2];
	BOOL bInxErr[2];
} PMC_ERRORSTATE;

typedef struct PMC_RUNSTATE
{
	int iErrorState;
	BOOL bHomIsRun[2];
	BOOL bJogIsRun[2];
	BOOL bPgmIsRun[2];

} PMC_RUNSTATE;

typedef struct HOMMOD
{
	int iErrorState;
	BOOL bEnable[2];
	BOOL bDirection[2];
} HOMMOD;

typedef struct PARALLELSTATE
{
	int iErrorState;
	BOOL HOME;
	BOOL STROBE;
	BOOL X;
	BOOL Y;
	BOOL MODE0;
	BOOL MODE1;
	BOOL STEPSL0;
	BOOL STEPSL1;
	BOOL STEPSL2;
	BOOL STEPSL3;
	BOOL STEPSL4;
	BOOL STEPSL5;
} PARALLELSTATE;

typedef struct AXISSTATE
{
	int iErrorState;
	BOOL bHomSig0[2];
	BOOL bHomSig1[2];
	BOOL bHomSig2[2];
	BOOL LmtP[2];
	BOOL LmtM[2];
	BOOL EMG[2];
	BOOL bInput0Lev[2];
	BOOL bInput1Lev[2];
} AXISSTATE;

#endif
#endif